@@ -7,6 +7,7 @@ mod candle;
 mod interval;
 mod liquidity;
 mod order_canceled;
+mod order_filter;
 mod order_status;
 mod order_type;
 mod order;
@@ -25,6 +26,7 @@ pub use candle::Candle;
 pub use interval::Interval;
 pub use liquidity::Liquidity;
 pub use order_canceled::OrderCanceled;
+pub use order_filter::OrderFilter;
 pub use order_status::OrderStatus;
 pub use order_type::OrderType;
 pub use order::Order;
